==> spip_4.0.4.orig.tar.xz: plugins-dist/forum/lang/forum_bg.php <==
<?php
// This is a SPIP language file  --  Ceci est un fichier langue de SPIP
// extrait automatiquement de https://trad.spip.net/tradlang_module/forum?lang_cible=bg
// ** ne pas modifier le fichier **

if (!defined('_ECRIRE_INC_VERSION')) {
	return;
}

$GLOBALS[$GLOBALS['idx_lang']] = array(

	// B
	'bouton_radio_articles_futurs' => 'само за бъдещи статии (без действие на базата данни).',
	'bouton_radio_articles_tous' => 'към всички статии без изключение.',
	'bouton_radio_articles_tous_sauf_forum_desactive' => 'към всички статии, освен тези с деактивирани форуми.',
	'bouton_radio_enregistrement_obligatoire' => 'Задължителна регистрация (преди да можете да участвате, необходимо е да се абонирате като запишете електронния си адрес).',
	'bouton_radio_moderation_priori' => 'Предварителна регистрация (
 приносите от съобщения ще бъдат показвани само след одобрение от
 администраторите).', # MODIF
	'bouton_radio_modere_abonnement' => 'изисква се регистрация',
	'bouton_radio_modere_posteriori' => 'последваща модерация', # MODIF
	'bouton_radio_modere_priori' => 'предварителна модерация', # MODIF
	'bouton_radio_publication_immediate' => 'Незабавно публикуване на съобщения
 (приносите от съобщения ще бъдат показани в момента, в който бъдат изпратени; след това
 администраторите могат да ги изтриват).',

	// F
	'form_pet_message_commentaire' => 'Коментар?',
	'forum' => 'Форум',
	'forum_acces_refuse' => 'Вече нямате достъп до тези форуми.',
	'forum_attention_dix_caracteres' => '<b>Предупреждение!</b> съобщението трябва да е по-дълго от 10 знака.',
	'forum_attention_trois_caracteres' => '<b>Предупреждение!</b> полето Относно трябва да е по-дълго от 3 знака.',
	'forum_avez_selectionne' => 'Вие сте избрали:',
	'forum_cliquer_retour' => 'Изберете <a href=\'@retour_forum@\'>тук</a> за да продължите.',
	'forum_forum' => 'форум',
	'forum_info_modere' => 'Форумът се модерира предварително: Вашият принос ще се появи след одобрението от администратора.', # MODIF
	'forum_lien_hyper' => '<b>Хипертекстова препратка</b> (по избор)', # MODIF
	'forum_message_definitif' => 'Последно съобщение: изпращане до сайта',
	'forum_message_trop_long' => 'Съобщението е прекалено дълго. Максимално можете да впишете 20000 знака.', # MODIF
	'forum_ne_repondez_pas' => 'Не отговаряйте на съобщението директно, а във форума на следния адрес:', # MODIF
	'forum_page_url' => '(Ако съобщението Ви се отнася към вече публикувана статия или към Интернет страница с повече информация, моля впишете името на старницата и нейния URL адрес по-долу).',
	'forum_poste_par' => 'Изпратено е съобщение @parauteur@, следващо статията.', # MODIF
	'forum_qui_etes_vous' => '<b>Кой сте Вие?</b> (по избор)', # MODIF
	'forum_texte' => 'Текст на съобщението:', # MODIF
	'forum_titre' => 'Тема:', # MODIF
	'forum_url' => 'URL адрес:', # MODIF
	'forum_valider' => 'Одобряване на избора',
	'forum_voir_avant' => 'Преглед на съобщението преди изпращане', # MODIF
	'forum_votre_email' => 'Вашият електронен адрес:', # MODIF
	'forum_votre_nom' => 'Вашето име (или псевдоним):', # MODIF
	'forum_vous_enregistrer' => 'Преди да участвате в този форум
  е необходимо да се регистрирате. Благодарим,
  че отворихте личния си идентификатор,
  който Ви бе предоставен. Ако все още не сте регистрирани, необходимо е да',
	'forum_vous_inscrire' => 'регистриране.',

	// I
	'icone_poster_message' => 'Изпращане на съобщение',
	'icone_suivi_forum' => 'Принос от съобщение(я) в публичния форум: @nb_forums@ съобщения',
	'icone_suivi_forums' => 'Развитие на форумите',
	'icone_supprimer_message' => 'Изтриване на съобщението',
	'icone_valider_message' => 'Одобряване на съобщението',
	'info_activer_forum_public' => '<i>За достъп до публичните форуми, изберете от модерирането режим "по подразбиране":</i>', # MODIF
	'info_appliquer_choix_moderation' => 'Прилагане на избора за модерация:',
	'info_desactiver_forum_public' => 'Дезактивиране на публичните
 форуми. Те могат да бътат активирани отново в определени
 случаи за статиите, а забранени за рубриките, новините и др.',
	'info_envoi_forum' => 'Изпращане на форумите до авторите на статии',
	'info_fonctionnement_forum' => 'Работа на форума:',
	'info_gauche_suivi_forum_2' => 'Страницата <i>Допълнения във форумите</i> е инструмент за управление на сайта (а не зона за дискусии или за публикации). Тя показва целия принос от съобщения в публичния форум на статията и позволява боравенето с тези съобщения.', # MODIF
	'info_liens_syndiques_3' => 'форуми',
	'info_liens_syndiques_4' => 'са',
	'info_liens_syndiques_5' => 'форум',
	'info_liens_syndiques_6' => 'е',
	'info_liens_syndiques_7' => 'очакват одобрение.',
	'info_mode_fonctionnement_defaut_forum_public' => 'Режим "по подразбиране" на публичните форуми',
	'info_option_email' => 'Когато посетител на сайта изпраща до форума съобщение,
  свързано със статия, авторът на статията може да бъде уведомяван
  по електронна поща за това. Искате ли да използвате тази възможност?', # MODIF
	'info_pas_de_forum' => 'без форум',
	'item_activer_forum_administrateur' => 'Позволяване на администраторски форум',
	'item_desactiver_forum_administrateur' => 'Без администраторски форум',

	// L
	'lien_reponse_article' => 'Отговор на статията',
	'lien_reponse_breve_2' => 'Отговор на новината',
	'lien_reponse_rubrique' => 'Отговор в рубриката',
	'lien_reponse_site_reference' => 'Отговор на свързания сайт:', # MODIF

	// O
	'onglet_messages_internes' => 'Вътрешни съобщения',
	'onglet_messages_publics' => 'Публични съобщения',
	'onglet_messages_vide' => 'Съобщения без текст',

	// R
	'repondre_message' => 'Отговор на съобщението',

	// T
	'titre_cadre_forum_administrateur' => 'Затворен форум за администратори',
	'titre_cadre_forum_interne' => 'Вътрешен форум',
	'titre_forum' => 'Форум',
	'titre_forum_suivi' => 'Допълнения във форумите',
	'titre_page_forum_suivi' => 'Допълнения във форумите'
);

==> spip_4.2.14+dfsg.orig.tar.xz: plugins-dist/forum/lang/forum_bg.php <==
<?php
// This is a SPIP language file  --  Ceci est un fichier langue de SPIP
// extrait automatiquement de https://trad.spip.net/tradlang_module/forum?lang_cible=bg
// ** ne pas modifier le fichier **

return [

	// B
	'bouton_radio_articles_futurs' => 'само за бъдещи статии (без действие на базата данни).',
	'bouton_radio_articles_tous' => 'към всички статии без изключение.',
	'bouton_radio_articles_tous_sauf_forum_desactive' => 'към всички статии, освен тези с деактивирани форуми.',
	'bouton_radio_enregistrement_obligatoire' => 'Задължителна регистрация (преди да можете да участвате, необходимо е да се абонирате като запишете електронния си адрес).',
	'bouton_radio_moderation_priori' => 'Предварителна регистрация (
 приносите от съобщения ще бъдат показвани само след одобрение от
 администраторите).', # MODIF
	'bouton_radio_modere_abonnement' => 'изисква се регистрация',
	'bouton_radio_modere_posteriori' => 'последваща модерация', # MODIF
	'bouton_radio_modere_priori' => 'предварителна модерация', # MODIF
	'bouton_radio_publication_immediate' => 'Незабавно публикуване на съобщения
 (приносите от съобщения ще бъдат показани в момента, в който бъдат изпратени; след това
 администраторите могат да ги изтриват).',

	// F
	'form_pet_message_commentaire' => 'Коментар?',
	'forum' => 'Форум',
	'forum_acces_refuse' => 'Вече нямате достъп до тези форуми.',
	'forum_attention_dix_caracteres' => '<b>Предупреждение!</b> съобщението трябва да е по-дълго от 10 знака.',
	'forum_attention_trois_caracteres' => '<b>Предупреждение!</b> полето Относно трябва да е по-дълго от 3 знака.',
	'forum_avez_selectionne' => 'Вие сте избрали:',
	'forum_cliquer_retour' => 'Изберете <a href=\'@retour_forum@\'>тук</a> за да продължите.',
	'forum_forum' => 'форум',
	'forum_info_modere' => 'Форумът се модерира предварително: Вашият принос ще се появи след одобрението от администратора.', # MODIF
	'forum_lien_hyper' => '<b>Хипертекстова препратка</b> (по избор)', # MODIF
	'forum_message_definitif' => 'Последно съобщение: изпращане до сайта',
	'forum_message_trop_long' => 'Съобщението е прекалено дълго. Максимално можете да впишете 20000 знака.', # MODIF
	'forum_ne_repondez_pas' => 'Не отговаряйте на съобщението директно, а във форума на следния адрес:', # MODIF
	'forum_page_url' => '(Ако съобщението Ви се отнася към вече публикувана статия или към Интернет страница с повече информация, моля впишете името на старницата и нейния URL адрес по-долу).',
	'forum_poste_par' => 'Изпратено е съобщение @parauteur@, следващо статията.', # MODIF
	'forum_qui_etes_vous' => '<b>Кой сте Вие?</b> (по избор)', # MODIF
	'forum_texte' => 'Текст на съобщението:', # MODIF
	'forum_titre' => 'Тема:', # MODIF
	'forum_url' => 'URL адрес:', # MODIF
	'forum_valider' => 'Одобряване на избора',
	'forum_voir_avant' => 'Преглед на съобщението преди изпращане', # MODIF
	'forum_votre_email' => 'Вашият електронен адрес:', # MODIF
	'forum_votre_nom' => 'Вашето име (или псевдоним):', # MODIF
	'forum_vous_enregistrer' => 'Преди да участвате в този форум
  е необходимо да се регистрирате. Благодарим,
  че отворихте личния си идентификатор,
  който Ви бе предоставен. Ако все още не сте регистрирани, необходимо е да',
	'forum_vous_inscrire' => 'регистриране.',

	// I
	'icone_poster_message' => 'Изпращане на съобщение',
	'icone_suivi_forum' => 'Принос от съобщение(я) в публичния форум: @nb_forums@ съобщения',
	'icone_suivi_forums' => 'Развитие на форумите',
	'icone_supprimer_message' => 'Изтриване на съобщението',
	'icone_valider_message' => 'Одобряване на съобщението',
	'info_activer_forum_public' => '<i>За достъп до публичните форуми, изберете от модерирането режим "по подразбиране":</i>', # MODIF
	'info_appliquer_choix_moderation' => 'Прилагане на избора за модерация:',
	'info_desactiver_forum_public' => 'Дезактивиране на публичните
 форуми. Те могат да бътат активирани отново в определени
 случаи за статиите, а забранени за рубриките, новините и др.',
	'info_envoi_forum' => 'Изпращане на форумите до авторите на статии',
	'info_fonctionnement_forum' => 'Работа на форума:',
	'info_gauche_suivi_forum_2' => 'Страницата <i>Допълнения във форумите</i> е инструмент за управление на сайта (а не зона за дискусии или за публикации). Тя показва целия принос от съобщения в публичния форум на статията и позволява боравенето с тези съобщения.', # MODIF
	'info_liens_syndiques_3' => 'форуми',
	'info_liens_syndiques_4' => 'са',
	'info_liens_syndiques_5' => 'форум',
	'info_liens_syndiques_6' => 'е',
	'info_liens_syndiques_7' => 'очакват одобрение.',
	'info_mode_fonctionnement_defaut_forum_public' => 'Режим "по подразбиране" на публичните форуми',
	'info_option_email' => 'Когато посетител на сайта изпраща до форума съобщение,
  свързано със статия, авторът на статията може да бъде уведомяван
  по електронна поща за това. Искате ли да използвате тази възможност?', # MODIF
	'info_pas_de_forum' => 'без форум',
	'item_activer_forum_administrateur' => 'Позволяване на администраторски форум',
	'item_desactiver_forum_administrateur' => 'Без администраторски форум',

	// L
	'lien_reponse_article' => 'Отговор на статията',
	'lien_reponse_breve_2' => 'Отговор на новината',
	'lien_reponse_rubrique' => 'Отговор в рубриката',
	'lien_reponse_site_reference' => 'Отговор на свързания сайт:', # MODIF

	// O
	'onglet_messages_internes' => 'Вътрешни съобщения',
	'onglet_messages_publics' => 'Публични съобщения',
	'onglet_messages_vide' => 'Съобщения без текст',

	// R
	'repondre_message' => 'Отговор на съобщението',

	// T
	'titre_cadre_forum_administrateur' => 'Затворен форум за администратори',
	'titre_cadre_forum_interne' => 'Вътрешен форум',
	'titre_forum' => 'Форум',
	'titre_forum_suivi' => 'Допълнения във форумите',
	'titre_page_forum_suivi' => 'Допълнения във форумите',
];
